---
name: Team recommendation
about: Nominate yourself or another Organization Member to join a team
title: ''
labels: nomination
assignees: ''

---

*For details on how this process works, please see our [contributor roles documentation](https://github.com/instructlab/community/blob/main/CONTRIBUTOR_ROLES.md)*

**Which member are you nominating for a team change?**
<!-- The GitHub username of the Organization Member you are nominating -->

**Which team are you nominating for this member for?**
<!-- CLI Triages or CLI Maintainers, see the above document for more details -->

**Make your case here: Why should the nominated member be on the proposed team?**
<!-- Feel free to write a brief testimonial here, try to include as many Pull Requests, Issues, etc. as possible

TIP: You can use the following queries to link to work items the nominee as been involved with
Pull Requests Authored: https://github.com/instructlab/instructlab/pulls?q=is%3Apr+author%3A{GITHUB_USERNAME}+
Pull Requests Reviewed: https://github.com/instructlab/instructlab/pulls?q=is%3Apr+reviewed-by%3A{GITHUB_USERNAME}+
Issues Created:         https://github.com/instructlab/instructlab/issues?q=is%3Aissue+author%3A{GITHUB_USERNAME}+
-->
